# R script for the assignment on co-evolution of alcohol consumption
# & friendship

# load RSiena commands:
library(RSiena)

# set working directory to where the data are:
setwd("C:/~  Statistical SNA GMMSGE16 2010-11/labs")
list.files()

# Read data sets:
net1 <- as.matrix(read.table("s50-network1.dat"))
net2 <- as.matrix(read.table("s50-network2.dat"))
net3 <- as.matrix(read.table("s50-network3.dat"))
alcohol <- as.matrix(read.table("s50-alcohol.dat"))

# No need to recode data or identify missings (this data set does not
# contain any missing data).

# Identify dependent network variable:
friendship <- sienaNet(array(c(net1, net2, net3), dim=c(50, 50, 3)))

# Identify dependent behavior variable:
drinking <- sienaNet(alcohol, type="behavior")

# Bind data together for Siena analysis:
CoEvolutionData <- sienaDataCreate(friendship,drinking)

# Create effects object for model specification:
CoEvolutionEffects <- getEffects(CoEvolutionData)

# Write first descriptive results to protocol file (optional):
print01Report(CoEvolutionData, CoEvolutionEffects,
  modelname = 'CoEvol-init')

# Specify the model according to the assignment.
# First the control effects that are not yet included by default:
CoEvolutionEffects <- includeEffects(CoEvolutionEffects,transTrip,cycle3)
CoEvolutionEffects
# Now sender, receiver and homophily effects for friendship formation:
CoEvolutionEffects 
 <- includeEffects(CoEvolutionEffects,egoX,altX,simX,interaction1="drinking")
CoEvolutionEffects
# Now indegree, outdegree and assimilation effects for drinking:
CoEvolutionEffects 
 <- includeEffects(CoEvolutionEffects,name="drinking",avSim,indeg,outdeg,
    interaction1="friendship")
CoEvolutionEffects
# Note that you need to additionally specify 'name="drinking"' because
# the default for 'name' is the network variable (here "friendship").

# Now create a model object:
CoEvolutionModel <- sienaModelCreate(useStdInits = TRUE, 
  projname = 'CoEvol-results')

# Estimate the model:
CoEvolutionResults <- siena07(CoEvolutionModel, data=CoEvolutionData,
  effects=CoEvolutionEffects, batch=FALSE, verbose=FALSE)
